pub struct ImguiRenderRoutine {
pub renderer: Renderer,
}Expand description
An instance of a render routine, holding in imgui_wgpu renderer.
Fields
renderer: RendererImplementations
Sourceimpl ImguiRenderRoutine
impl ImguiRenderRoutine
Sourcepub fn new(
renderer: &Renderer,
imgui: &mut Context,
output_format: TextureFormat,
) -> Self
pub fn new( renderer: &Renderer, imgui: &mut Context, output_format: TextureFormat, ) -> Self
Imgui will always output gamma-encoded color. It will determine if to do this in the shader manually based on the output format.
pub fn add_to_graph<'node>( &'node mut self, graph: &mut RenderGraph<'node>, draw_data: &'node DrawData, output: RenderTargetHandle, )